@@ -20,14 +20,18 @@ from win32com.client import constants
 # * SETUP
 
 # Get the instance of Word running on this machine. Start it if necessary.
-try:
-    COM_WORD = win32com.client.gencache.EnsureDispatch("Word.Application")
-except AttributeError:
-    # We end up here if this cryptic error occurs.
-    # https://stackoverflow.com/questions/52889704/python-win32com-excel-com-model-started-generating-errors
-    # https://mail.python.org/pipermail/python-win32/2007-August/006147.html
-    shutil.rmtree(win32com.__gen_path__)
-    COM_WORD = win32com.client.gencache.EnsureDispatch("Word.Application")
+EXCEPTION = True
+NUM_TRIES = 0
+while EXCEPTION and NUM_TRIES < 10:
+    NUM_TRIES += 1
+    try:
+        COM_WORD = win32com.client.gencache.EnsureDispatch("Word.Application")
+        EXCEPTION = False  # We only get here if COM_WORD is set successfully
+    except AttributeError:
+        # We end up here if this cryptic error occurs.
+        # https://stackoverflow.com/questions/52889704/python-win32com-excel-com-model-started-generating-errors
+        # https://mail.python.org/pipermail/python-win32/2007-August/006147.html
+        shutil.rmtree(win32com.__gen_path__)
 
 # * -------------------------------------------------------------------------------- * #
 # * CLASSES * #
@@ -44,7 +48,7 @@ class Document(AbstractContextManager):
 
     The context-specific attribute ``com`` exposes the ``win32com.<...>.Document`` class
     directly, a COM object representation of the document which has slightly different
-    syntax and access rules than regular Python. For example, collections are
+    syntax and access rules than regular Python. For example, COM object collections are
     one-indexed rather than zero-indexed. The ``comments`` attribute exposes certain
     aspects of the ``win32com.<...>.Comments`` class in a convenient, Pythonic
     :py:class:`Comments` class.
@@ -55,7 +59,7 @@ class Document(AbstractContextManager):
         Path to the document. May be a string.
     save_on_exit: Optional[bool]
         Whether to save the document when leaving context. Informs the attribute
-        :py:attr:`save_on_exit`.  **Default**: True.
+        :py:attr:`save_on_exit`.  **Default**: ``True``.
     close_on_exit: Optional[bool]
         Whether to close the document when leaving context. Informs the attribute
         :py:attr:`close_on_exit`. **Default**: Closes documents that were not already
@@ -93,20 +97,16 @@ class Document(AbstractContextManager):
         # Check if the document is already open, set close_on_exit accordingly
         if self.close_on_exit is None:
             already_open_documents = [doc.Name for doc in COM_WORD.Documents]
-            if self.path.name in already_open_documents:
-                self.close_on_exit = False
-            else:
-                self.close_on_exit = True
-
+            self.close_on_exit = self.path.name not in already_open_documents
         # Track nested levels of context
         self.context_count = 0
 
     def __getattr__(self, name):
-        """Only called on an ``AttributeError``. Handle context-specific attributes."""
+        """Handle context-specific attributes. Only called on an ``AttributeError``."""
 
-        if name in {"com", "comments"}:
+        if name in {"com", "comments"}:  # context-specific attributes
             message = "Attribute only exists in context."
-        else:
+        else:  # the rest
             message = None
 
         raise AttributeError(message)
@@ -165,6 +165,11 @@ class Document(AbstractContextManager):
 class Comments(abc.Sequence):
     """The comments in an open Word document.
 
+    The native COM object ``win32com.<...>.Comments`` is one-indexed and has nothing
+    analogus to Python's ``slice`` indexing. This class enables zero-indexed,
+    single-item or ``slice`` access to instances of :py:class:`Comment`. The sequence of
+    comments can also be reversed with :py:func:`reversed`.
+
     Parameters
     ----------
     document: Document
@@ -185,23 +190,15 @@ class Comments(abc.Sequence):
         self.com = self.in_document.com.Comments
 
     def __getitem__(self, index):  # pylint: disable=inconsistent-return-statements
-        """Get comments.
-
-        The native COM object is one-indexed and has nothing analogous to Python's
-        ``slice`` indexing. This method enables zero-indexed, single-item or ``slice``
-        access to :py:class:`Comment` instances in :py:class:`Comments`.
-        """
 
         if isinstance(index, int):
             key = index
             com_comment = self.com(key + 1)  # COM is 1-indexed
-            comment = Comment(com_comment, self)
-            return comment
+            return Comment(com_comment, self)
 
         if isinstance(index, slice):
             keys = range(*index.indices(len(self)))  # coerce keys to object bounds
-            comments = [self[key] for key in keys]  # recursive call on each key
-            return comments
+            return [self[key] for key in keys]  # recursive call on each key
 
     def __iter__(self) -> Iterator:
         return (Comment(com_comment, self) for com_comment in self.com)
@@ -269,6 +266,7 @@ class Comment:
         com_active_window = self.in_document.com.ActiveWindow
         com_active_selection = com_active_window.Selection
         original_cursor_position = com_active_selection.Range
+        original_pane_count = com_active_window.Panes.Count  # if > 1, rev pane visible
 
         # Check whether the cursor is inside any comment
         com_active_window.Panes(1).Activate()  # Ensure we're in the main pane
@@ -288,10 +286,13 @@ class Comment:
         self.range.com.Select()
         com_active_selection.Text = text
 
-        # Restore print view and cursor position
+        # Restore print view, cursor position, and pane layout
         com_active_window.ActivePane.Close()  # Close the comments pane that comes up
         com_active_window.ActivePane.View.Type = constants.wdPrintView
         original_cursor_position.Select()
+        if original_pane_count > 1:  # If revisions pane was visible before
+            # Make it visible again
+            com_active_window.View.SplitSpecial = constants.wdPaneRevisions
 
 
 class Range:
@@ -312,7 +313,7 @@ class Range:
 
     @property
     def text(self) -> str:
-        """:str: Convenience property returning thisrange's text."""
+        """:str: Convenience property returning this range's text."""
         return self.com.Text
 
     def __init__(self, com_range):
@@ -375,42 +376,47 @@ def try_com(
         Whatever is returned from the COM method.
     """
 
+    # Accept either a single error or a list of errors
     if not except_errors:
         except_errors = []
     elif not isinstance(except_errors, list):
         except_errors = [except_errors]
 
+    # Accept no messages, a single message, or a list of messages
     if not messages:
         messages = [""] * len(except_errors)
     if not isinstance(messages, list):
         messages = [messages]
 
     try:
-        returns = com_method(**kwargs)
-
-    except pywintypes.com_error as error:  # pylint: disable=no-member
+        # Apply kwargs to the method, or return the method itself if no kwargs
+        returns = com_method(**kwargs) if kwargs else com_method
+    except pywintypes.com_error as error:
         returns = None
         error_caught = False
         for except_error, user_message in zip(except_errors, messages):
             if (
                 error.hresult == except_error.hresult
+                and error.excepinfo  # Some errors don't have an excepinfo
                 and error.excepinfo[-1] == except_error.scode
             ):
                 com_error_message = f"COM Error: {error}"
                 if user_message:
-                    message = user_message + " " + com_error_message
+                    message = f"{user_message} {com_error_message}"
                 else:
                     message = com_error_message
                 warn(message)
                 error_caught = True
-
+                break
         if not error_caught:
             raise error
-
     return returns
 
 
 ERRORS: Dict[str, ComError] = {
-    "command_not_available": ComError(-2147352567, -2146823683)
+    "bad_filename": ComError(-2147352567, -2146824128),
+    "command_not_available": ComError(-2147352567, -2146823683),
+    "no_args_passed": ComError(-2147352567, -2147352571),
+    "rpc_server_unavailable": ComError(-2147023174, None),
 }
 """:Dict[str, ComError]: A :py:class:`dict` of named :py:class:`ComError` errors."""
