@@ -12,7 +12,13 @@ def quit_word():
 
 def quit_word_safely():
     """Quit Word if no documents are open."""
-    if not com.COM_WORD.Documents:
+    documents = com.try_com(
+        com.COM_WORD.Documents,
+        except_errors=[
+            com.ERRORS["rpc_server_unavailable"],  # Word isn't open anymore anyways
+        ],
+    )
+    if not documents.Count:
         quit_word()
 
 
@@ -28,7 +34,7 @@ def get_active_document(
         ``True``.
     close_on_exit
         Whether to close the document when exiting a ``with`` context. **Default:**
-        Don't close the document on exit.
+        ``False``.
     """
 
     return com.Document(
